# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added

-

### Fixed

-

### Changed

-

### Removed

-

## [2.0.0] - 2025-05-04

### Added

- use imdb and fuzzy match for intelligent matching
- add --watch to make continuous watching optional
- support for more patterns

## [1.0.0] - 2025-05-04

### Added

- First release
- Ability to run fixer on a list of files in a directory
- Auto run when changes are detected in the directory

## [0.0.1] - 2025-04-30

### Added

- Stub release

[unreleased]: https://github.com/viseshrp/reelname/compare/v2.0.0...HEAD
[2.0.0]: https://github.com/viseshrp/reelname/releases/tag/v2.0.0
[1.0.0]: https://github.com/viseshrp/reelname/releases/tag/v1.0.0
[0.0.1]: https://github.com/viseshrp/reelname/releases/tag/v0.0.1
